@@ -38,6 +38,7 @@
 #include <osmocom/hnbgw/tdefs.h>
 #include <osmocom/hnbgw/mgw_fsm.h>
 #include <osmocom/hnbgw/ps_rab_ass_fsm.h>
+#include <osmocom/hnbgw/kpi.h>
 
 enum map_sccp_fsm_state {
 	MAP_SCCP_ST_INIT,
@@ -215,10 +216,12 @@ static int handle_rx_sccp(struct osmo_fsm_inst *fi, struct msgb *ranap_msg)
 			LOGPFSML(fi, LOGL_DEBUG, "rx from SCCP: RANAP %s\n",
 				 get_value_string(ranap_procedure_code_vals, message->procedureCode));
 
+			kpi_ranap_process_dl(map, message);
+
 			switch (message->procedureCode) {
 			case RANAP_ProcedureCode_id_RAB_Assignment:
 				/* mgw_fsm_alloc_and_handle_rab_ass_req() takes ownership of (ranap) message */
-				return handle_rab_ass_req(map, ranap_msg, message);
+				return handle_cs_rab_ass_req(map, ranap_msg, message);
 			case RANAP_ProcedureCode_id_Iu_Release:
 				/* Any IU Release will terminate the MGW FSM, the message itsself is not passed to the
 				 * FSM code. It is just forwarded normally by map_rua_tx_dt() below. */
@@ -239,6 +242,8 @@ static int handle_rx_sccp(struct osmo_fsm_inst *fi, struct msgb *ranap_msg)
 			LOGPFSML(fi, LOGL_DEBUG, "rx from SCCP: RANAP %s\n",
 				 get_value_string(ranap_procedure_code_vals, message->procedureCode));
 
+			kpi_ranap_process_dl(map, message);
+
 			switch (message->procedureCode) {
 
 			case RANAP_ProcedureCode_id_RAB_Assignment:
@@ -452,6 +457,7 @@ static void map_sccp_wait_rlsd_action(struct osmo_fsm_inst *fi, uint32_t event,
 		handle_rx_sccp(fi, ranap_msg);
 		return;
 
+	case MAP_SCCP_EV_RAN_LINK_LOST:
 	case MAP_SCCP_EV_USER_ABORT:
 	case MAP_SCCP_EV_CN_LINK_LOST:
 		/* Stop waiting for RLSD, send RLSD now. */
